@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2013, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2020, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,11 +27,13 @@ class About : public QDialog
     Q_OBJECT
 
 public:
-    About(QWidget *parent = 0);
+    About(QWidget *parent = nullptr);
     void retranslateUi();
+    void setLanguage(const QString lang) { m_lang = lang; }
 
 private:
     Ui::AboutClass ui;
+    QString m_lang;
 };
 
 #endif // ABOUT_H
