@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2013, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2020, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,46 +21,37 @@
 
 #include <QDialog>
 #include <QAbstractButton>
-#include "pianopalette.h"
+#include <drumstick/pianopalette.h>
 
 namespace Ui {
     class ColorDialog;
 }
 
+using namespace drumstick::widgets;
+
 class ColorDialog : public QDialog
 {
     Q_OBJECT
-    
 public:
-
-    explicit ColorDialog(QWidget *parent = 0);
+    explicit ColorDialog(bool hiliteOnly, QWidget *parent = nullptr);
     ~ColorDialog();
-    PianoPalette *currentPalette();
-    PianoPalette *getPalette(int pal);
-    QList<QString> availablePaletteNames();
-    QColor getColor(int i);
-    void saveCurrentPalette();
     void retranslateUi();
+    int selectedPalette() const;
 
 public slots:
     void loadPalette(int i);
+    void accept() override;
 
 private slots:
     void onAnyColorWidgetClicked(int i);
     void resetCurrentPalette();
 
 private:
-    void initializePaletteStrings();
-    void initializePalettes();
-    void resetPaletteSingle(PianoPalette *palette);
-    void resetPaletteDouble(PianoPalette *palette);
-    void resetPaletteChannels(PianoPalette *palette);
-    void resetPaletteScale(PianoPalette *palette);
     void refreshPalette();
 
-    Ui::ColorDialog *m_ui;
-    QList<PianoPalette *> m_paletteList;
-    PianoPalette *m_currentPalette;
+    Ui::ColorDialog* m_ui;
+    bool m_hilite;
+    PianoPalette m_workingPalette;
 };
 
 #endif // COLORDIALOG_H
