@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2013, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2020, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ class ColorWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ColorWidget(QWidget *parent = 0);
+    explicit ColorWidget(QWidget *parent = nullptr);
 
     QString colorName() const { return m_colorName; }
     void setColorName(const QString value);
@@ -35,8 +35,8 @@ public:
 
     void disable();
 
-    void mousePressEvent(QMouseEvent *);
-    void paintEvent(QPaintEvent *);
+    void mousePressEvent(QMouseEvent *) override;
+    void paintEvent(QPaintEvent *) override;
 
 signals:
     void clicked();
