@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2013, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2020, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,20 +19,20 @@
 #ifndef KMAPDIALOG_H
 #define KMAPDIALOG_H
 
+#include <QDialog>
 #include "ui_kmapdialog.h"
 #include "keyboardmap.h"
-#include <QDialog>
 
 class KMapDialog : public QDialog
 {
     Q_OBJECT
 
 public:
-    KMapDialog(QWidget *parent = 0);
+    KMapDialog(QWidget *parent = nullptr);
     void load(const QString fileName);
     void save(const QString fileName);
-    void displayMap(const KeyboardMap* map);
-    void getMap(KeyboardMap* map);
+    void displayMap(const VMPKKeyboardMap* map);
+    void getMap(VMPKKeyboardMap* map);
     void retranslateUi();
 
 public slots:
@@ -44,7 +44,7 @@ private:
 
     QPushButton* m_btnOpen;
     QPushButton* m_btnSave;
-    KeyboardMap m_map;
+    VMPKKeyboardMap m_map;
     Ui::KMapDialogClass ui;
 };
 
